echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v xmllint) == "" ]] && echo "Installing xmllint" && extension --install xmllint && echo "Finished xmllint"
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then
	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
	[[ $(dot -Tpng -V && echo $?) == "" ]] && echo "Installing graphviz" && extension --install graphviz --rebuild && echo "Finished graphviz"
	[[ $(command -v xmlto) == "" ]] && echo "Installing xmlto" && extension --install xmlto && echo "Finished xmlto"
	[ ! -d /usr/share/xml/docbook/xml-dtd-* ] && echo "Installing docbook4_xml" && extension --install docbook4_xml && echo "Finished docbook4_xml"
	[ ! -d /usr/share/xml/docbook/xsl-stylesheets-nons-* ] && echo "Installing docbook_xsl_nons" && extension --install docbook_xsl_nons && echo "Finished docbook_xsl_nons"
	[[ $(command -v xsltproc) == "" ]] && echo "Installing libxslt" && extension --install libxslt && echo "Finished libxslt"
fi

if [ $BUILD_ALL == "false" ] && [[ $(pkg-config wayland-scanner --exists && echo $?) == 0 ]] && [[ $(pkg-config wayland-scanner --modversion) != "1.24.0" ]]; then
	echo "wayland" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "wayland" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
